/*
 * Copyright (c) 2020 yifu4cloud Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.yifu.cloud.plus.v1.yifu.admin.service;

import cn.hutool.core.lang.tree.Tree;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yifu.cloud.plus.v1.yifu.admin.api.entity.SysDept;
import com.yifu.cloud.plus.v1.yifu.admin.api.vo.DeptTreeSelectVO;
import com.yifu.cloud.plus.v1.yifu.admin.api.vo.SysDeptMoveVo;
import com.yifu.cloud.plus.v1.yifu.admin.api.vo.SysDeptVo;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.core.vo.UserPermissionVo;

import java.util.List;

/**
 * <p>
 * 部门管理 服务类
 * </p>
 *
 * @author lengleng
 * @since 2019/2/1
 */
public interface SysDeptService extends IService<SysDept> {

	/**
	 * 查询部门树菜单
	 * @return 树
	 */
	List<Tree<Long>> listDeptTrees();

	/**
	 * 查询用户部门树
	 * @return
	 */
	List<Tree<Long>> listCurrentUserDeptTrees();

	/**
	 * 添加信息部门
	 * @param sysDept
	 * @return
	 */
	Boolean saveDept(SysDept sysDept);

	/**
	 * 删除部门
	 * @param id 部门 ID
	 * @return 成功、失败
	 */
	Boolean removeDeptById(Long id);

	/**
	 * 更新部门
	 * @param sysDept 部门信息
	 * @return 成功、失败
	 */
	Boolean updateDeptById(SysDept sysDept);

	/**
	 * 查找指定部门的子部门id列表
	 * @param deptId 部门id
	 * @return List<Long>
	 */
	List<Long> listChildDeptId(Long deptId);


	/**
	 * 从ldap中获取部门
	 * @return R
	 */
	R updateDeptByLdap();


	/**
	 * 客户服务平台——获取部门树（用于下拉选择）
	 *
	 * @param dept 部门信息
	 * @return 下拉树结构列表
	 */
	List<DeptTreeSelectVO> cspDeptTreeSelect(SysDeptVo dept);

	/**
	 * 客户服务平台——获取部门树（带部门下人数）
	 *
	 * @param dept 部门信息
	 * @return 部门树列表
	 */
	List<DeptTreeSelectVO> cspDeptTree(SysDeptVo dept);

	/**
	 * 客户服务平台——获取花名册的部门树（带部门下人数）
	 *
	 * @param dept 部门信息
	 * @param authority 用户在当前项目下的权限
	 * @return 部门树列表
	 */
	List<DeptTreeSelectVO> cspRosterTree(SysDeptVo dept, UserPermissionVo authority);

	/**
	 * 客户服务平台——添加部门
	 *
	 * @param dept 部门信息
	 * @return 结果
	 */
	R<String> saveCspDept(SysDept dept);

	/**
	 * 客户服务平台——编辑部门
	 *
	 * @param dept 部门信息
	 * @return 结果
	 */
	R<String> updateCspDept(SysDept dept);

	/**
	 * 客户服务平台——删除部门
	 *
	 * @param id 部门id
	 * @return 结果
	 */
	R<String> removeCspDeptById(Long id);

	/**
	 * 客户服务平台——获取项目下部门总数
	 *
	 * @param projectNo 项目编码
	 * @return R<Integer> 部门总数
	 */
	Integer cspDeptCount(String projectNo);

	R<Boolean> cspUpdateDept(SysDeptMoveVo dept);

	/**
	 * 客户服务平台——获取项目下已删除的部门
	 * @return R<String> 删除部门的ID集合
	 * @author chenyuxi
	 * @since 1.9.7
	 */
	String cspDelDeptIds(String projectNo);

}
